@@ -99,45 +99,38 @@ class hack:
             else:
                print(color_c + "Port -- ", port, " -- [OPEN]")
         fanc1()
-    def encrypt_the_file_txt():
+    def encrypt_the_file_txt(file,password):
         import os
-        while True:
-            import pyAesCrypt
+        import pyAesCrypt
+        print("---------------------------------------------------------------")
+        bufferSize = 64*1024
+        try: 
+            pyAesCrypt.decryptFile(str(file), str(os.path.splitext(file)[0]), password, bufferSize)
+            os.remove(file)
+        except FileNotFoundError: 
+            print("[x] File not found!")
+        except ValueError: 
+            print("[x] Password is Fasle!")
+        else: 
+            print("[+] File '"+str(os.path.splitext(file)[0])+"' successfully saved!")
+        finally: 
             print("---------------------------------------------------------------")
-            file=input("File name: ")
-            password=input("Password: ")
-            bufferSize = 64*1024
-            try: 
-                pyAesCrypt.decryptFile(str(file), str(os.path.splitext(file)[0]), password, bufferSize)
-            except FileNotFoundError: 
-                print("[x] File not found!")
-            except ValueError: 
-                print("[x] Password is Fasle!")
-            else: 
-                print("[+] File '"+str(os.path.splitext(file)[0])+"' successfully saved!")
-            finally: 
-                print("---------------------------------------------------------------")
-            if a == 'stop':
-                a = a
-    def ZAR_encrypt_the_file_txt():
+    def ZAR_encrypt_the_file_txt(file,password):
         import os
-        while True:
-            if 1 == 1:
-                import pyAesCrypt
-                print("---------------------------------------------------------------" )
-                file=input("File name: ")
-                password=input("Password: ")
-                bufferSize = 64*1024
-                try: 
-                    pyAesCrypt.encryptFile(str(file), str(file)+".crp", password, bufferSize)
-                except FileNotFoundError: 
-                    print("[x] File not found!")
-                else: 
-                    print("[+] File '"+str(file)+".crp' successfully saved!")
-                finally: 
-                    print("---------------------------------------------------------------")
-            if a == 'stop':
-                a = a
+        import pyAesCrypt
+        print("---------------------------------------------------------------" )
+        bufferSize = 64*1024
+        try: 
+            pyAesCrypt.encryptFile(str(file), str(file)+".crp", password, bufferSize)
+            os.remove(file)
+        except FileNotFoundError: 
+            print("[x] File not found!")
+        except OSError:
+            print('[x] File not found!')
+        else: 
+            print("[+] File '"+str(file)+".crp' successfully saved!")
+        finally: 
+            print("---------------------------------------------------------------")
     def crash(site):
         import threading
         import requests
@@ -156,6 +149,8 @@ class hack:
         requests.get("https://"+site)
         try:
             print('True')
+        except:
+            print('False')
 class cmd():
     def command():
         print('Для получения сведений об определенной команде наберите HELP <имя команды>')
@@ -264,4 +259,7 @@ class cmd():
         os.system(a)
     def cmd(a):
         import os
-        os.startfile(a)
\ No newline at end of file
+        os.startfile(a)
+    def cd(cd):
+        import os
+        os.chdir(cd)
